/*******************************************************************\

Module: Pointer Dereferencing

Author: Daniel Kroening, kroening@kroening.com

\*******************************************************************/

/// \file
/// Pointer Dereferencing

#include "dereference_callback.h"

dereference_callbackt::~dereference_callbackt()
{
}
